Text class

Created by

─▄▀─▄▀ ──▀──▀ █▀▀▀▀▀█▄ █░░░░░█─█ ▀▄▄▄▄▄▀▀

Rafaelbarbosatec on 01/12/21

Constructors

Text({bool bold = false, String color = '#000000', String fontFamily = 'sans-serif', String hAlign = 'left', bool italic = false, bool kerning = true, int pixelSize = 16, bool strikeout = false, String text = '', bool underline = false, String vAlign = 'top', bool wrap = false})
Text.fromJson(Map<String, dynamic> json)

Properties

bold → bool
final
color → String
final
fontFamily → String
final
hAlign → String
final
hashCode → int
The hash code for this object.
no setterinherited
italic → bool
final
kerning → bool
final
pixelSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strikeout → bool
final
text → String
final
underline → bool
final
vAlign → String
final
wrap → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited